@@ -82,7 +82,7 @@ enum class Id : uint32_t {
     DATASAVER = 46,
     XBOX = 47,
     QQ = 48,
-    TIKTOK = 49,
+    DEPR49 = 49,  // Deprecated: TikTok - not a protocol
     RTSP = 50,
     MAIL_IMAPS = 51,
     ICECAST = 52,
@@ -397,11 +397,11 @@ enum class Id : uint32_t {
 
 const std::unordered_map<Id, const char *, ndEnumHasher> Tags = {
     { Id::AFP, "AFP" },
-    { Id::AFP, "ApacheThrift" },
     { Id::AJP, "AJP" },
     { Id::ALICLOUD, "Alibaba/Cloud" },
     { Id::AMONG_US, "AmongUs" },
     { Id::AMQP, "AMQP" },
+    { Id::APACHE_THRIFT, "Apache/Thrift" },
     { Id::APPLE_PUSH, "Apple/Push" },
     { Id::ARMAGETRON, "Armagetron" },
     { Id::AVAST, "AVAST" },
@@ -426,6 +426,7 @@ const std::unordered_map<Id, const char *, ndEnumHasher> Tags = {
     { Id::CROSSFIRE, "Crossfire" },
     { Id::CRYNET, "CryNetwork" },
     { Id::CSGO, "CSGO" },
+    { Id::DATASAVER, "DataSaver" },
     { Id::DHCP, "DHCP" },
     { Id::DHCPV6, "DHCPv6" },
     { Id::DIAMETER, "Diameter" },
@@ -860,7 +861,6 @@ const std::unordered_map<uint16_t, Id> Protos = {
     { NDPI_PROTOCOL_TEREDO, Id::TEREDO },
     { NDPI_PROTOCOL_TFTP, Id::TFTP },
     { NDPI_PROTOCOL_THREEMA, Id::THREEMA },
-    { NDPI_PROTOCOL_TIKTOK, Id::TIKTOK },
     { NDPI_PROTOCOL_TINC, Id::TINC },
     { NDPI_PROTOCOL_TIVOCONNECT, Id::TIVOCONNECT },
     { NDPI_PROTOCOL_TLS, Id::TLS },
@@ -1055,7 +1055,7 @@ const std::vector<uint16_t> Disabled = {
     // (NetFlix)
     NDPI_PROTOCOL_NTOP,  // Not a protocol: ID# 26 (ntop)
     NDPI_PROTOCOL_NVIDIA,  // Not a protocol: ID# 342
-    // (GeForceNow)
+    // (Nvidia)
     NDPI_PROTOCOL_OCS,  // Not a protocol: ID# 218 (OCS)
     NDPI_PROTOCOL_OCSP,  // Not a protocol (HTTP): ID# 63
     // (OCSP)
@@ -1163,6 +1163,7 @@ const std::vector<uint16_t> Disabled = {
     NDPI_PROTOCOL_ROBLOX,  // Not a protocol: ID# 346 (Roblox)
     NDPI_PROTOCOL_MULLVAD,  // Not a protocol: ID# 348 (Mullvad)
     NDPI_PROTOCOL_SINA_WEIBO,  // Not a protocol: ID# 356 (SinaWeibo)
+    NDPI_PROTOCOL_TIKTOK,  // Not a protocol: ID# 49 (TikTok)
 };
 
 const std::vector<uint16_t> Free = {};
