@@ -94,7 +94,6 @@ ndInstance::~ndInstance() {
             }
         }
 #endif
-
         for (auto i : thread_detection) {
             if (p == 0) i.second->Terminate();
             else delete i.second;
@@ -261,7 +260,7 @@ ndInstance::InitializeConfig(int argc, char * const argv[]) {
             ndGC_SetFlag(ndGlobalFlags::IGNORE_IFACE_CONFIGS, true);
             break;
         case '?':
-            cerr << "Try `--help' for more information.\n";
+            cerr << "Try --help for more information.\n";
             return ndEnumCast(ConfigResult, INVALID_OPTION);
         case 'c': conf_filename = optarg; break;
         case 'd':
@@ -298,7 +297,7 @@ ndInstance::InitializeConfig(int argc, char * const argv[]) {
             return ndCR_Pack(DISABLE_PLUGIN,
               (EnableInformatics(false)) ? 0 : 1);
         case '?':
-            cerr << "Try `--help' for more information.\n";
+            cerr << "Try --help for more information.\n";
             return ndEnumCast(ConfigResult, INVALID_OPTION);
         default: break;
         }
@@ -535,6 +534,12 @@ ndInstance::InitializeConfig(int argc, char * const argv[]) {
         }
     }
 
+    if (argc > optind) {
+        cerr << "Invalid option: " << argv[optind] << endl;
+        cerr << "Try --help for more information." << endl;
+        return ndEnumCast(ConfigResult, INVALID_OPTION);
+    }
+
     Reload(false);
 
     optind = 1;
@@ -1931,8 +1936,7 @@ bool ndInstance::DisplayAgentStatus(void) {
 int ndInstance::Run(void) {
     if (version.empty()) {
         nd_printf(
-          "%s: Instance configuration not "
-          "initialized.\n",
+          "%s: Instance configuration not initialized.\n",
           tag.c_str());
         goto ndInstance_RunReturn;
     }
@@ -1961,13 +1965,29 @@ int ndInstance::Run(void) {
     if (ndGC_USE_NETLINK) netlink = new ndNetlink();
 #endif
 
-    try {
 #ifdef _ND_ENABLE_CONNTRACK
-        if (ndGC_USE_CONNTRACK) {
+    if (ndGC_USE_CONNTRACK) {
+        try {
             thread_conntrack = new ndConntrackThread(ndGC.ca_conntrack);
             thread_conntrack->Create();
         }
+        catch (exception &e) {
+            if (thread_conntrack != nullptr) {
+                delete thread_conntrack;
+                thread_conntrack = nullptr;
+            }
+
+            ndGC_SetFlag(ndGlobalFlags::USE_CONNTRACK, false);
+
+            nd_printf(
+              "%s: WARNING: Conntrack support disabled by "
+              "exception: %s\n",
+              tag.c_str(), e.what());
+        }
+    }
 #endif
+
+    try {
         plugins.Load();
 
         int16_t cpu =
@@ -2153,11 +2173,34 @@ void *ndInstance::ndInstance::Entry(void) {
             ProcessUpdate(thread_capture);
             break;
         case InstanceEvent::UPDATE_NAPI:
-            nd_dprintf("%s: received IPC: [%d] %s\n",
-              tag.c_str(), ipc, "Netify API update");
             if (ndGC_USE_NAPI || ndGC_AUTO_INFORMATICS) {
-                if (api_manager.Update()) {
+                switch (api_manager.Update()) {
+                case ndNetifyApiManager::UpdateResult::OK:
+                    nd_dprintf(
+                      "%s: received IPC: [%d] %s: %s\n",
+                      tag.c_str(), ipc, "Netify API update",
+                      "OK");
+                    break;
+                case ndNetifyApiManager::UpdateResult::RELOAD:
+                    nd_dprintf(
+                      "%s: received IPC: [%d] %s: %s\n",
+                      tag.c_str(), ipc, "Netify API update",
+                      "reload");
                     Reload(false, false);
+                    break;
+                case ndNetifyApiManager::UpdateResult::RELOAD_BROADCAST:
+                    nd_dprintf(
+                      "%s: received IPC: [%d] %s: %s\n",
+                      tag.c_str(), ipc, "Netify API update",
+                      "reload (broadcast)");
+                    Reload(true, false);
+                    break;
+                case ndNetifyApiManager::UpdateResult::ERROR:
+                    nd_dprintf(
+                      "%s: received IPC: [%d] %s: %s\n",
+                      tag.c_str(), ipc, "Netify API update",
+                      "error");
+                    break;
                 }
             }
             break;
